==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/securityhub/kotlin/inputs/InsightFiltersNoteUpdatedAtArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.securityhub.kotlin.inputs

import com.pulumi.aws.securityhub.inputs.InsightFiltersNoteUpdatedAtArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 *
 * @property dateRange A configuration block of the date range for the date filter. See date_range below for more details.
 * @property end An end date for the date filter. Required with `start` if `date_range` is not specified.
 * @property start A start date for the date filter. Required with `end` if `date_range` is not specified.
 */
public data class InsightFiltersNoteUpdatedAtArgs(
    public val dateRange: Output<InsightFiltersNoteUpdatedAtDateRangeArgs>? = null,
    public val end: Output<String>? = null,
    public val start: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.aws.securityhub.inputs.InsightFiltersNoteUpdatedAtArgs> {
    override fun toJava(): com.pulumi.aws.securityhub.inputs.InsightFiltersNoteUpdatedAtArgs =
        com.pulumi.aws.securityhub.inputs.InsightFiltersNoteUpdatedAtArgs.builder()
            .dateRange(dateRange?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .end(end?.applyValue({ args0 -> args0 }))
            .start(start?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [InsightFiltersNoteUpdatedAtArgs].
 */
@PulumiTagMarker
public class InsightFiltersNoteUpdatedAtArgsBuilder internal constructor() {
    private var dateRange: Output<InsightFiltersNoteUpdatedAtDateRangeArgs>? = null

    private var end: Output<String>? = null

    private var start: Output<String>? = null

    /**
     * @param value A configuration block of the date range for the date filter. See date_range below for more details.
     */
    @JvmName("bdyqeakwvmkoaqqf")
    public suspend fun dateRange(`value`: Output<InsightFiltersNoteUpdatedAtDateRangeArgs>) {
        this.dateRange = value
    }

    /**
     * @param value An end date for the date filter. Required with `start` if `date_range` is not specified.
     */
    @JvmName("qbkurkmdlalxcuxj")
    public suspend fun end(`value`: Output<String>) {
        this.end = value
    }

    /**
     * @param value A start date for the date filter. Required with `end` if `date_range` is not specified.
     */
    @JvmName("imarirbucdltvhsg")
    public suspend fun start(`value`: Output<String>) {
        this.start = value
    }

    /**
     * @param value A configuration block of the date range for the date filter. See date_range below for more details.
     */
    @JvmName("minmwftjjhfbaywn")
    public suspend fun dateRange(`value`: InsightFiltersNoteUpdatedAtDateRangeArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dateRange = mapped
    }

    /**
     * @param argument A configuration block of the date range for the date filter. See date_range below for more details.
     */
    @JvmName("pkpbgoecygmgwmyr")
    public suspend
    fun dateRange(argument: suspend InsightFiltersNoteUpdatedAtDateRangeArgsBuilder.() -> Unit) {
        val toBeMapped = InsightFiltersNoteUpdatedAtDateRangeArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.dateRange = mapped
    }

    /**
     * @param value An end date for the date filter. Required with `start` if `date_range` is not specified.
     */
    @JvmName("coxlovvumdrgavfm")
    public suspend fun end(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.end = mapped
    }

    /**
     * @param value A start date for the date filter. Required with `end` if `date_range` is not specified.
     */
    @JvmName("vyvrskeugxwfpnyn")
    public suspend fun start(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.start = mapped
    }

    internal fun build(): InsightFiltersNoteUpdatedAtArgs = InsightFiltersNoteUpdatedAtArgs(
        dateRange = dateRange,
        end = end,
        start = start,
    )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/securityhub/kotlin/inputs/InsightFiltersNoteUpdatedAtArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.securityhub.kotlin.inputs

import com.pulumi.aws.securityhub.inputs.InsightFiltersNoteUpdatedAtArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 *
 * @property dateRange A configuration block of the date range for the date filter. See date_range below for more details.
 * @property end An end date for the date filter. Required with `start` if `date_range` is not specified.
 * @property start A start date for the date filter. Required with `end` if `date_range` is not specified.
 */
public data class InsightFiltersNoteUpdatedAtArgs(
    public val dateRange: Output<InsightFiltersNoteUpdatedAtDateRangeArgs>? = null,
    public val end: Output<String>? = null,
    public val start: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.aws.securityhub.inputs.InsightFiltersNoteUpdatedAtArgs> {
    override fun toJava(): com.pulumi.aws.securityhub.inputs.InsightFiltersNoteUpdatedAtArgs =
        com.pulumi.aws.securityhub.inputs.InsightFiltersNoteUpdatedAtArgs.builder()
            .dateRange(dateRange?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .end(end?.applyValue({ args0 -> args0 }))
            .start(start?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [InsightFiltersNoteUpdatedAtArgs].
 */
@PulumiTagMarker
public class InsightFiltersNoteUpdatedAtArgsBuilder internal constructor() {
    private var dateRange: Output<InsightFiltersNoteUpdatedAtDateRangeArgs>? = null

    private var end: Output<String>? = null

    private var start: Output<String>? = null

    /**
     * @param value A configuration block of the date range for the date filter. See date_range below for more details.
     */
    @JvmName("cndgnbiownubkymp")
    public suspend fun dateRange(`value`: Output<InsightFiltersNoteUpdatedAtDateRangeArgs>) {
        this.dateRange = value
    }

    /**
     * @param value An end date for the date filter. Required with `start` if `date_range` is not specified.
     */
    @JvmName("ummqgtursbskljio")
    public suspend fun end(`value`: Output<String>) {
        this.end = value
    }

    /**
     * @param value A start date for the date filter. Required with `end` if `date_range` is not specified.
     */
    @JvmName("rlhuiyacociqklty")
    public suspend fun start(`value`: Output<String>) {
        this.start = value
    }

    /**
     * @param value A configuration block of the date range for the date filter. See date_range below for more details.
     */
    @JvmName("tudyjuocogloiwcu")
    public suspend fun dateRange(`value`: InsightFiltersNoteUpdatedAtDateRangeArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dateRange = mapped
    }

    /**
     * @param argument A configuration block of the date range for the date filter. See date_range below for more details.
     */
    @JvmName("lswsntjpncvvxsnx")
    public suspend fun dateRange(argument: suspend InsightFiltersNoteUpdatedAtDateRangeArgsBuilder.() -> Unit) {
        val toBeMapped = InsightFiltersNoteUpdatedAtDateRangeArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.dateRange = mapped
    }

    /**
     * @param value An end date for the date filter. Required with `start` if `date_range` is not specified.
     */
    @JvmName("hgytoeaebeelvhdu")
    public suspend fun end(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.end = mapped
    }

    /**
     * @param value A start date for the date filter. Required with `end` if `date_range` is not specified.
     */
    @JvmName("vhuxcukklfklealu")
    public suspend fun start(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.start = mapped
    }

    internal fun build(): InsightFiltersNoteUpdatedAtArgs = InsightFiltersNoteUpdatedAtArgs(
        dateRange = dateRange,
        end = end,
        start = start,
    )
}
